@@ -8,13 +8,12 @@
 // option. This file may not be copied, modified, or distributed
 // except according to those terms.
 
-#![deny(warnings)]
-
 use std::fs::File;
 use std::path::{Path, PathBuf};
 use std::process::{Command, Stdio};
-use std::{fs, env};
 use std::time::{SystemTime, UNIX_EPOCH};
+use std::{env, fs};
+use std::thread;
 
 /// A helper macro to `unwrap` a result except also print out details like:
 ///
@@ -26,10 +25,12 @@ use std::time::{SystemTime, UNIX_EPOCH};
 /// using a `Result` with `try!`, but this may change one day...
 #[macro_export]
 macro_rules! t {
-    ($e:expr) => (match $e {
-        Ok(e) => e,
-        Err(e) => panic!("{} failed with {}", stringify!($e), e),
-    })
+    ($e:expr) => {
+        match $e {
+            Ok(e) => e,
+            Err(e) => panic!("{} failed with {}", stringify!($e), e),
+        }
+    };
 }
 
 pub fn run(cmd: &mut Command) {
@@ -46,14 +47,17 @@ pub fn run_silent(cmd: &mut Command) {
 pub fn try_run_silent(cmd: &mut Command) -> bool {
     let status = match cmd.status() {
         Ok(status) => status,
-        Err(e) => fail(&format!("failed to execute command: {:?}\nerror: {}",
-                                cmd, e)),
+        Err(e) => fail(&format!(
+            "failed to execute command: {:?}\nerror: {}",
+            cmd, e
+        )),
     };
     if !status.success() {
-        println!("\n\ncommand did not execute successfully: {:?}\n\
-                  expected success, got: {}\n\n",
-                 cmd,
-                 status);
+        println!(
+            "\n\ncommand did not execute successfully: {:?}\n\
+             expected success, got: {}\n\n",
+            cmd, status
+        );
     }
     status.success()
 }
@@ -67,36 +71,40 @@ pub fn run_suppressed(cmd: &mut Command) {
 pub fn try_run_suppressed(cmd: &mut Command) -> bool {
     let output = match cmd.output() {
         Ok(status) => status,
-        Err(e) => fail(&format!("failed to execute command: {:?}\nerror: {}",
-                                cmd, e)),
+        Err(e) => fail(&format!(
+            "failed to execute command: {:?}\nerror: {}",
+            cmd, e
+        )),
     };
     if !output.status.success() {
-        println!("\n\ncommand did not execute successfully: {:?}\n\
-                  expected success, got: {}\n\n\
-                  stdout ----\n{}\n\
-                  stderr ----\n{}\n\n",
-                 cmd,
-                 output.status,
-                 String::from_utf8_lossy(&output.stdout),
-                 String::from_utf8_lossy(&output.stderr));
+        println!(
+            "\n\ncommand did not execute successfully: {:?}\n\
+             expected success, got: {}\n\n\
+             stdout ----\n{}\n\
+             stderr ----\n{}\n\n",
+            cmd,
+            output.status,
+            String::from_utf8_lossy(&output.stdout),
+            String::from_utf8_lossy(&output.stderr)
+        );
     }
     output.status.success()
 }
 
-pub fn gnu_target(target: &str) -> String {
+pub fn gnu_target(target: &str) -> &str {
     match target {
-        "i686-pc-windows-msvc" => "i686-pc-win32".to_string(),
-        "x86_64-pc-windows-msvc" => "x86_64-pc-win32".to_string(),
-        "i686-pc-windows-gnu" => "i686-w64-mingw32".to_string(),
-        "x86_64-pc-windows-gnu" => "x86_64-w64-mingw32".to_string(),
-        s => s.to_string(),
+        "i686-pc-windows-msvc" => "i686-pc-win32",
+        "x86_64-pc-windows-msvc" => "x86_64-pc-win32",
+        "i686-pc-windows-gnu" => "i686-w64-mingw32",
+        "x86_64-pc-windows-gnu" => "x86_64-w64-mingw32",
+        s => s,
     }
 }
 
 pub fn make(host: &str) -> PathBuf {
-    if host.contains("bitrig") || host.contains("dragonfly") ||
-        host.contains("freebsd") || host.contains("netbsd") ||
-        host.contains("openbsd") {
+    if host.contains("bitrig") || host.contains("dragonfly") || host.contains("freebsd")
+        || host.contains("netbsd") || host.contains("openbsd")
+    {
         PathBuf::from("gmake")
     } else {
         PathBuf::from("make")
@@ -106,23 +114,27 @@ pub fn make(host: &str) -> PathBuf {
 pub fn output(cmd: &mut Command) -> String {
     let output = match cmd.stderr(Stdio::inherit()).output() {
         Ok(status) => status,
-        Err(e) => fail(&format!("failed to execute command: {:?}\nerror: {}",
-                                cmd, e)),
+        Err(e) => fail(&format!(
+            "failed to execute command: {:?}\nerror: {}",
+            cmd, e
+        )),
     };
     if !output.status.success() {
-        panic!("command did not execute successfully: {:?}\n\
-                expected success, got: {}",
-               cmd,
-               output.status);
+        panic!(
+            "command did not execute successfully: {:?}\n\
+             expected success, got: {}",
+            cmd, output.status
+        );
     }
     String::from_utf8(output.stdout).unwrap()
 }
 
 pub fn rerun_if_changed_anything_in_dir(dir: &Path) {
-    let mut stack = dir.read_dir().unwrap()
-                       .map(|e| e.unwrap())
-                       .filter(|e| &*e.file_name() != ".git")
-                       .collect::<Vec<_>>();
+    let mut stack = dir.read_dir()
+        .unwrap()
+        .map(|e| e.unwrap())
+        .filter(|e| &*e.file_name() != ".git")
+        .collect::<Vec<_>>();
     while let Some(entry) = stack.pop() {
         let path = entry.path();
         if entry.file_type().unwrap().is_dir() {
@@ -135,7 +147,9 @@ pub fn rerun_if_changed_anything_in_dir(dir: &Path) {
 
 /// Returns the last-modified time for `path`, or zero if it doesn't exist.
 pub fn mtime(path: &Path) -> SystemTime {
-    fs::metadata(path).and_then(|f| f.modified()).unwrap_or(UNIX_EPOCH)
+    fs::metadata(path)
+        .and_then(|f| f.modified())
+        .unwrap_or(UNIX_EPOCH)
 }
 
 /// Returns whether `dst` is up to date given that the file or files in `src`
@@ -164,9 +178,42 @@ pub struct NativeLibBoilerplate {
     pub out_dir: PathBuf,
 }
 
+impl NativeLibBoilerplate {
+    /// On OSX we don't want to ship the exact filename that compiler-rt builds.
+    /// This conflicts with the system and ours is likely a wildly different
+    /// version, so they can't be substituted.
+    ///
+    /// As a result, we rename it here but we need to also use
+    /// `install_name_tool` on OSX to rename the commands listed inside of it to
+    /// ensure it's linked against correctly.
+    pub fn fixup_sanitizer_lib_name(&self, sanitizer_name: &str) {
+        if env::var("TARGET").unwrap() != "x86_64-apple-darwin" {
+            return
+        }
+
+        let dir = self.out_dir.join("build/lib/darwin");
+        let name = format!("clang_rt.{}_osx_dynamic", sanitizer_name);
+        let src = dir.join(&format!("lib{}.dylib", name));
+        let new_name = format!("lib__rustc__{}.dylib", name);
+        let dst = dir.join(&new_name);
+
+        println!("{} => {}", src.display(), dst.display());
+        fs::rename(&src, &dst).unwrap();
+        let status = Command::new("install_name_tool")
+            .arg("-id")
+            .arg(format!("@rpath/{}", new_name))
+            .arg(&dst)
+            .status()
+            .expect("failed to execute `install_name_tool`");
+        assert!(status.success());
+    }
+}
+
 impl Drop for NativeLibBoilerplate {
     fn drop(&mut self) {
-        t!(File::create(self.out_dir.join("rustbuild.timestamp")));
+        if !thread::panicking() {
+            t!(File::create(self.out_dir.join("rustbuild.timestamp")));
+        }
     }
 }
 
@@ -176,16 +223,18 @@ impl Drop for NativeLibBoilerplate {
 // If Err is returned, then everything is up-to-date and further build actions can be skipped.
 // Timestamps are created automatically when the result of `native_lib_boilerplate` goes out
 // of scope, so all the build actions should be completed until then.
-pub fn native_lib_boilerplate(src_name: &str,
-                              out_name: &str,
-                              link_name: &str,
-                              search_subdir: &str)
-                              -> Result<NativeLibBoilerplate, ()> {
+pub fn native_lib_boilerplate(
+    src_name: &str,
+    out_name: &str,
+    link_name: &str,
+    search_subdir: &str,
+) -> Result<NativeLibBoilerplate, ()> {
     let current_dir = PathBuf::from(env::var("CARGO_MANIFEST_DIR").unwrap());
     let src_dir = current_dir.join("..").join(src_name);
     rerun_if_changed_anything_in_dir(&src_dir);
 
-    let out_dir = env::var_os("RUSTBUILD_NATIVE_DIR").unwrap_or(env::var_os("OUT_DIR").unwrap());
+    let out_dir = env::var_os("RUSTBUILD_NATIVE_DIR").unwrap_or_else(||
+        env::var_os("OUT_DIR").unwrap());
     let out_dir = PathBuf::from(out_dir).join(out_name);
     t!(fs::create_dir_all(&out_dir));
     if link_name.contains('=') {
@@ -193,32 +242,50 @@ pub fn native_lib_boilerplate(src_name: &str,
     } else {
         println!("cargo:rustc-link-lib=static={}", link_name);
     }
-    println!("cargo:rustc-link-search=native={}", out_dir.join(search_subdir).display());
+    println!(
+        "cargo:rustc-link-search=native={}",
+        out_dir.join(search_subdir).display()
+    );
 
     let timestamp = out_dir.join("rustbuild.timestamp");
     if !up_to_date(Path::new("build.rs"), &timestamp) || !up_to_date(&src_dir, &timestamp) {
-        Ok(NativeLibBoilerplate { src_dir: src_dir, out_dir: out_dir })
+        Ok(NativeLibBoilerplate {
+            src_dir: src_dir,
+            out_dir: out_dir,
+        })
     } else {
         Err(())
     }
 }
 
-pub fn sanitizer_lib_boilerplate(sanitizer_name: &str) -> Result<NativeLibBoilerplate, ()> {
-    let (link_name, search_path) = match &*env::var("TARGET").unwrap() {
+pub fn sanitizer_lib_boilerplate(sanitizer_name: &str)
+    -> Result<(NativeLibBoilerplate, String), ()>
+{
+    let (link_name, search_path, apple) = match &*env::var("TARGET").unwrap() {
         "x86_64-unknown-linux-gnu" => (
             format!("clang_rt.{}-x86_64", sanitizer_name),
             "build/lib/linux",
+            false,
         ),
         "x86_64-apple-darwin" => (
-            format!("dylib=clang_rt.{}_osx_dynamic", sanitizer_name),
+            format!("clang_rt.{}_osx_dynamic", sanitizer_name),
             "build/lib/darwin",
+            true,
         ),
         _ => return Err(()),
     };
-    native_lib_boilerplate("libcompiler_builtins/compiler-rt",
-                           sanitizer_name,
-                           &link_name,
-                           search_path)
+    let to_link = if apple {
+        format!("dylib=__rustc__{}", link_name)
+    } else {
+        format!("static={}", link_name)
+    };
+    let lib = native_lib_boilerplate(
+        "libcompiler_builtins/compiler-rt",
+        sanitizer_name,
+        &to_link,
+        search_path,
+    )?;
+    Ok((lib, link_name))
 }
 
 fn dir_up_to_date(src: &Path, threshold: SystemTime) -> bool {
