@@ -65,87 +65,204 @@ types! {
     pub struct uint64x2_t(u64, u64);
 }
 
+/// ARM-specific type containing two `int8x8_t` vectors.
+#[derive(Copy, Clone)]
+pub struct int8x8x2_t(pub int8x8_t, pub int8x8_t);
+/// ARM-specific type containing three `int8x8_t` vectors.
+#[derive(Copy, Clone)]
+pub struct int8x8x3_t(pub int8x8_t, pub int8x8_t, pub int8x8_t);
+/// ARM-specific type containing four `int8x8_t` vectors.
+#[derive(Copy, Clone)]
+pub struct int8x8x4_t(pub int8x8_t, pub int8x8_t, pub int8x8_t, pub int8x8_t);
+
+/// ARM-specific type containing two `uint8x8_t` vectors.
+#[derive(Copy, Clone)]
+pub struct uint8x8x2_t(pub uint8x8_t, pub uint8x8_t);
+/// ARM-specific type containing three `uint8x8_t` vectors.
+#[derive(Copy, Clone)]
+pub struct uint8x8x3_t(pub uint8x8_t, pub uint8x8_t, pub uint8x8_t);
+/// ARM-specific type containing four `uint8x8_t` vectors.
+#[derive(Copy, Clone)]
+pub struct uint8x8x4_t(
+    pub uint8x8_t,
+    pub uint8x8_t,
+    pub uint8x8_t,
+    pub uint8x8_t,
+);
+
+/// ARM-specific type containing two `poly8x8_t` vectors.
+#[derive(Copy, Clone)]
+pub struct poly8x8x2_t(pub poly8x8_t, pub poly8x8_t);
+/// ARM-specific type containing three `poly8x8_t` vectors.
+#[derive(Copy, Clone)]
+pub struct poly8x8x3_t(pub poly8x8_t, pub poly8x8_t, pub poly8x8_t);
+/// ARM-specific type containing four `poly8x8_t` vectors.
+#[derive(Copy, Clone)]
+pub struct poly8x8x4_t(
+    pub poly8x8_t,
+    pub poly8x8_t,
+    pub poly8x8_t,
+    pub poly8x8_t,
+);
+
 #[allow(improper_ctypes)]
 extern "C" {
     #[cfg_attr(
-        target_arch = "aarch64", link_name = "llvm.aarch64.neon.frsqrte.v2f32"
+        target_arch = "aarch64",
+        link_name = "llvm.aarch64.neon.frsqrte.v2f32"
+    )]
+    #[cfg_attr(
+        target_arch = "arm",
+        link_name = "llvm.arm.neon.vrsqrte.v2f32"
     )]
-    #[cfg_attr(target_arch = "arm", link_name = "llvm.arm.neon.vrsqrte.v2f32")]
     fn frsqrte_v2f32(a: float32x2_t) -> float32x2_t;
 
     #[cfg_attr(target_arch = "arm", link_name = "llvm.arm.neon.vpmins.v8i8")]
     #[cfg_attr(
-        target_arch = "aarch64", link_name = "llvm.aarch64.neon.sminp.v8i8"
+        target_arch = "aarch64",
+        link_name = "llvm.aarch64.neon.sminp.v8i8"
     )]
     fn vpmins_v8i8(a: int8x8_t, b: int8x8_t) -> int8x8_t;
-    #[cfg_attr(target_arch = "arm", link_name = "llvm.arm.neon.vpmins.v4i16")]
     #[cfg_attr(
-        target_arch = "aarch64", link_name = "llvm.aarch64.neon.sminp.v4i16"
+        target_arch = "arm",
+        link_name = "llvm.arm.neon.vpmins.v4i16"
+    )]
+    #[cfg_attr(
+        target_arch = "aarch64",
+        link_name = "llvm.aarch64.neon.sminp.v4i16"
     )]
     fn vpmins_v4i16(a: int16x4_t, b: int16x4_t) -> int16x4_t;
-    #[cfg_attr(target_arch = "arm", link_name = "llvm.arm.neon.vpmins.v2i32")]
     #[cfg_attr(
-        target_arch = "aarch64", link_name = "llvm.aarch64.neon.sminp.v2i32"
+        target_arch = "arm",
+        link_name = "llvm.arm.neon.vpmins.v2i32"
+    )]
+    #[cfg_attr(
+        target_arch = "aarch64",
+        link_name = "llvm.aarch64.neon.sminp.v2i32"
     )]
     fn vpmins_v2i32(a: int32x2_t, b: int32x2_t) -> int32x2_t;
     #[cfg_attr(target_arch = "arm", link_name = "llvm.arm.neon.vpminu.v8i8")]
     #[cfg_attr(
-        target_arch = "aarch64", link_name = "llvm.aarch64.neon.uminp.v8i8"
+        target_arch = "aarch64",
+        link_name = "llvm.aarch64.neon.uminp.v8i8"
     )]
     fn vpminu_v8i8(a: uint8x8_t, b: uint8x8_t) -> uint8x8_t;
-    #[cfg_attr(target_arch = "arm", link_name = "llvm.arm.neon.vpminu.v4i16")]
     #[cfg_attr(
-        target_arch = "aarch64", link_name = "llvm.aarch64.neon.uminp.v4i16"
+        target_arch = "arm",
+        link_name = "llvm.arm.neon.vpminu.v4i16"
+    )]
+    #[cfg_attr(
+        target_arch = "aarch64",
+        link_name = "llvm.aarch64.neon.uminp.v4i16"
     )]
     fn vpminu_v4i16(a: uint16x4_t, b: uint16x4_t) -> uint16x4_t;
-    #[cfg_attr(target_arch = "arm", link_name = "llvm.arm.neon.vpminu.v2i32")]
     #[cfg_attr(
-        target_arch = "aarch64", link_name = "llvm.aarch64.neon.uminp.v2i32"
+        target_arch = "arm",
+        link_name = "llvm.arm.neon.vpminu.v2i32"
+    )]
+    #[cfg_attr(
+        target_arch = "aarch64",
+        link_name = "llvm.aarch64.neon.uminp.v2i32"
     )]
     fn vpminu_v2i32(a: uint32x2_t, b: uint32x2_t) -> uint32x2_t;
-    #[cfg_attr(target_arch = "arm", link_name = "llvm.arm.neon.vpmins.v2f32")]
     #[cfg_attr(
-        target_arch = "aarch64", link_name = "llvm.aarch64.neon.fminp.v2f32"
+        target_arch = "arm",
+        link_name = "llvm.arm.neon.vpmins.v2f32"
+    )]
+    #[cfg_attr(
+        target_arch = "aarch64",
+        link_name = "llvm.aarch64.neon.fminp.v2f32"
     )]
     fn vpminf_v2f32(a: float32x2_t, b: float32x2_t) -> float32x2_t;
 
     #[cfg_attr(target_arch = "arm", link_name = "llvm.arm.neon.vpmaxs.v8i8")]
     #[cfg_attr(
-        target_arch = "aarch64", link_name = "llvm.aarch64.neon.smaxp.v8i8"
+        target_arch = "aarch64",
+        link_name = "llvm.aarch64.neon.smaxp.v8i8"
     )]
     fn vpmaxs_v8i8(a: int8x8_t, b: int8x8_t) -> int8x8_t;
-    #[cfg_attr(target_arch = "arm", link_name = "llvm.arm.neon.vpmaxs.v4i16")]
     #[cfg_attr(
-        target_arch = "aarch64", link_name = "llvm.aarch64.neon.smaxp.v4i16"
+        target_arch = "arm",
+        link_name = "llvm.arm.neon.vpmaxs.v4i16"
+    )]
+    #[cfg_attr(
+        target_arch = "aarch64",
+        link_name = "llvm.aarch64.neon.smaxp.v4i16"
     )]
     fn vpmaxs_v4i16(a: int16x4_t, b: int16x4_t) -> int16x4_t;
-    #[cfg_attr(target_arch = "arm", link_name = "llvm.arm.neon.vpmaxs.v2i32")]
     #[cfg_attr(
-        target_arch = "aarch64", link_name = "llvm.aarch64.neon.smaxp.v2i32"
+        target_arch = "arm",
+        link_name = "llvm.arm.neon.vpmaxs.v2i32"
+    )]
+    #[cfg_attr(
+        target_arch = "aarch64",
+        link_name = "llvm.aarch64.neon.smaxp.v2i32"
     )]
     fn vpmaxs_v2i32(a: int32x2_t, b: int32x2_t) -> int32x2_t;
     #[cfg_attr(target_arch = "arm", link_name = "llvm.arm.neon.vpmaxu.v8i8")]
     #[cfg_attr(
-        target_arch = "aarch64", link_name = "llvm.aarch64.neon.umaxp.v8i8"
+        target_arch = "aarch64",
+        link_name = "llvm.aarch64.neon.umaxp.v8i8"
     )]
     fn vpmaxu_v8i8(a: uint8x8_t, b: uint8x8_t) -> uint8x8_t;
-    #[cfg_attr(target_arch = "arm", link_name = "llvm.arm.neon.vpmaxu.v4i16")]
     #[cfg_attr(
-        target_arch = "aarch64", link_name = "llvm.aarch64.neon.umaxp.v4i16"
+        target_arch = "arm",
+        link_name = "llvm.arm.neon.vpmaxu.v4i16"
+    )]
+    #[cfg_attr(
+        target_arch = "aarch64",
+        link_name = "llvm.aarch64.neon.umaxp.v4i16"
     )]
     fn vpmaxu_v4i16(a: uint16x4_t, b: uint16x4_t) -> uint16x4_t;
-    #[cfg_attr(target_arch = "arm", link_name = "llvm.arm.neon.vpmaxu.v2i32")]
     #[cfg_attr(
-        target_arch = "aarch64", link_name = "llvm.aarch64.neon.umaxp.v2i32"
+        target_arch = "arm",
+        link_name = "llvm.arm.neon.vpmaxu.v2i32"
+    )]
+    #[cfg_attr(
+        target_arch = "aarch64",
+        link_name = "llvm.aarch64.neon.umaxp.v2i32"
     )]
     fn vpmaxu_v2i32(a: uint32x2_t, b: uint32x2_t) -> uint32x2_t;
-    #[cfg_attr(target_arch = "arm", link_name = "llvm.arm.neon.vpmaxs.v2f32")]
     #[cfg_attr(
-        target_arch = "aarch64", link_name = "llvm.aarch64.neon.fmaxp.v2f32"
+        target_arch = "arm",
+        link_name = "llvm.arm.neon.vpmaxs.v2f32"
+    )]
+    #[cfg_attr(
+        target_arch = "aarch64",
+        link_name = "llvm.aarch64.neon.fmaxp.v2f32"
     )]
     fn vpmaxf_v2f32(a: float32x2_t, b: float32x2_t) -> float32x2_t;
 }
 
+#[cfg(target_arch = "arm")]
+#[allow(improper_ctypes)]
+extern "C" {
+    #[link_name = "llvm.arm.neon.vtbl1"]
+    fn vtbl1(a: int8x8_t, b: int8x8_t) -> int8x8_t;
+    #[link_name = "llvm.arm.neon.vtbl2"]
+    fn vtbl2(a: int8x8_t, b: int8x8_t, b: int8x8_t) -> int8x8_t;
+    #[link_name = "llvm.arm.neon.vtbl3"]
+    fn vtbl3(a: int8x8_t, b: int8x8_t, b: int8x8_t, c: int8x8_t) -> int8x8_t;
+    #[link_name = "llvm.arm.neon.vtbl4"]
+    fn vtbl4(
+        a: int8x8_t, b: int8x8_t, b: int8x8_t, c: int8x8_t, d: int8x8_t,
+    ) -> int8x8_t;
+
+    #[link_name = "llvm.arm.neon.vtbx1"]
+    fn vtbx1(a: int8x8_t, b: int8x8_t, b: int8x8_t) -> int8x8_t;
+    #[link_name = "llvm.arm.neon.vtbx2"]
+    fn vtbx2(a: int8x8_t, b: int8x8_t, b: int8x8_t, c: int8x8_t) -> int8x8_t;
+    #[link_name = "llvm.arm.neon.vtbx3"]
+    fn vtbx3(
+        a: int8x8_t, b: int8x8_t, b: int8x8_t, c: int8x8_t, d: int8x8_t,
+    ) -> int8x8_t;
+    #[link_name = "llvm.arm.neon.vtbx4"]
+    fn vtbx4(
+        a: int8x8_t, b: int8x8_t, b: int8x8_t, c: int8x8_t, d: int8x8_t,
+        e: int8x8_t,
+    ) -> int8x8_t;
+}
+
 /// Vector add.
 #[inline]
 #[target_feature(enable = "neon")]
@@ -647,6 +764,332 @@ pub unsafe fn vpmax_f32(a: float32x2_t, b: float32x2_t) -> float32x2_t {
     vpmaxf_v2f32(a, b)
 }
 
+/// Table look-up
+#[inline]
+#[cfg(target_arch = "arm")]
+#[cfg(target_endian = "little")]
+#[target_feature(enable = "neon,v7")]
+#[cfg_attr(test, assert_instr(vtbl))]
+pub unsafe fn vtbl1_s8(a: int8x8_t, b: int8x8_t) -> int8x8_t {
+    vtbl1(a, b)
+}
+
+/// Table look-up
+#[inline]
+#[cfg(target_arch = "arm")]
+#[cfg(target_endian = "little")]
+#[target_feature(enable = "neon,v7")]
+#[cfg_attr(test, assert_instr(vtbl))]
+pub unsafe fn vtbl1_u8(a: uint8x8_t, b: uint8x8_t) -> uint8x8_t {
+    ::mem::transmute(vtbl1(::mem::transmute(a), ::mem::transmute(b)))
+}
+
+/// Table look-up
+#[inline]
+#[cfg(target_arch = "arm")]
+#[cfg(target_endian = "little")]
+#[target_feature(enable = "neon,v7")]
+#[cfg_attr(test, assert_instr(vtbl))]
+pub unsafe fn vtbl1_p8(a: poly8x8_t, b: poly8x8_t) -> poly8x8_t {
+    ::mem::transmute(vtbl1(::mem::transmute(a), ::mem::transmute(b)))
+}
+
+/// Table look-up
+#[inline]
+#[cfg(target_arch = "arm")]
+#[cfg(target_endian = "little")]
+#[target_feature(enable = "neon,v7")]
+#[cfg_attr(test, assert_instr(vtbl))]
+pub unsafe fn vtbl2_s8(a: int8x8x2_t, b: int8x8_t) -> int8x8_t {
+    vtbl2(a.0, a.1, b)
+}
+
+/// Table look-up
+#[inline]
+#[cfg(target_arch = "arm")]
+#[cfg(target_endian = "little")]
+#[target_feature(enable = "neon,v7")]
+#[cfg_attr(test, assert_instr(vtbl))]
+pub unsafe fn vtbl2_u8(a: uint8x8x2_t, b: uint8x8_t) -> uint8x8_t {
+    ::mem::transmute(vtbl2(
+        ::mem::transmute(a.0),
+        ::mem::transmute(a.1),
+        ::mem::transmute(b),
+    ))
+}
+
+/// Table look-up
+#[inline]
+#[cfg(target_arch = "arm")]
+#[cfg(target_endian = "little")]
+#[target_feature(enable = "neon,v7")]
+#[cfg_attr(test, assert_instr(vtbl))]
+pub unsafe fn vtbl2_p8(a: poly8x8x2_t, b: uint8x8_t) -> poly8x8_t {
+    ::mem::transmute(vtbl2(
+        ::mem::transmute(a.0),
+        ::mem::transmute(a.1),
+        ::mem::transmute(b),
+    ))
+}
+
+/// Table look-up
+#[inline]
+#[cfg(target_arch = "arm")]
+#[cfg(target_endian = "little")]
+#[target_feature(enable = "neon,v7")]
+#[cfg_attr(test, assert_instr(vtbl))]
+pub unsafe fn vtbl3_s8(a: int8x8x3_t, b: int8x8_t) -> int8x8_t {
+    vtbl3(a.0, a.1, a.2, b)
+}
+
+/// Table look-up
+#[inline]
+#[cfg(target_arch = "arm")]
+#[cfg(target_endian = "little")]
+#[target_feature(enable = "neon,v7")]
+#[cfg_attr(test, assert_instr(vtbl))]
+pub unsafe fn vtbl3_u8(a: uint8x8x3_t, b: uint8x8_t) -> uint8x8_t {
+    ::mem::transmute(vtbl3(
+        ::mem::transmute(a.0),
+        ::mem::transmute(a.1),
+        ::mem::transmute(a.2),
+        ::mem::transmute(b),
+    ))
+}
+
+/// Table look-up
+#[inline]
+#[cfg(target_arch = "arm")]
+#[cfg(target_endian = "little")]
+#[target_feature(enable = "neon,v7")]
+#[cfg_attr(test, assert_instr(vtbl))]
+pub unsafe fn vtbl3_p8(a: poly8x8x3_t, b: uint8x8_t) -> poly8x8_t {
+    ::mem::transmute(vtbl3(
+        ::mem::transmute(a.0),
+        ::mem::transmute(a.1),
+        ::mem::transmute(a.2),
+        ::mem::transmute(b),
+    ))
+}
+
+/// Table look-up
+#[inline]
+#[cfg(target_arch = "arm")]
+#[cfg(target_endian = "little")]
+#[target_feature(enable = "neon,v7")]
+#[cfg_attr(test, assert_instr(vtbl))]
+pub unsafe fn vtbl4_s8(a: int8x8x4_t, b: int8x8_t) -> int8x8_t {
+    vtbl4(a.0, a.1, a.2, a.3, b)
+}
+
+/// Table look-up
+#[inline]
+#[cfg(target_arch = "arm")]
+#[cfg(target_endian = "little")]
+#[target_feature(enable = "neon,v7")]
+#[cfg_attr(test, assert_instr(vtbl))]
+pub unsafe fn vtbl4_u8(a: uint8x8x4_t, b: uint8x8_t) -> uint8x8_t {
+    ::mem::transmute(vtbl4(
+        ::mem::transmute(a.0),
+        ::mem::transmute(a.1),
+        ::mem::transmute(a.2),
+        ::mem::transmute(a.3),
+        ::mem::transmute(b),
+    ))
+}
+
+/// Table look-up
+#[inline]
+#[cfg(target_arch = "arm")]
+#[cfg(target_endian = "little")]
+#[target_feature(enable = "neon,v7")]
+#[cfg_attr(test, assert_instr(vtbl))]
+pub unsafe fn vtbl4_p8(a: poly8x8x4_t, b: uint8x8_t) -> poly8x8_t {
+    ::mem::transmute(vtbl4(
+        ::mem::transmute(a.0),
+        ::mem::transmute(a.1),
+        ::mem::transmute(a.2),
+        ::mem::transmute(a.3),
+        ::mem::transmute(b),
+    ))
+}
+
+/// Extended table look-up
+#[inline]
+#[cfg(target_arch = "arm")]
+#[cfg(target_endian = "little")]
+#[target_feature(enable = "neon,v7")]
+#[cfg_attr(test, assert_instr(vtbx))]
+pub unsafe fn vtbx1_s8(a: int8x8_t, b: int8x8_t, c: int8x8_t) -> int8x8_t {
+    vtbx1(a, b, c)
+}
+
+/// Extended table look-up
+#[inline]
+#[cfg(target_arch = "arm")]
+#[cfg(target_endian = "little")]
+#[target_feature(enable = "neon,v7")]
+#[cfg_attr(test, assert_instr(vtbx))]
+pub unsafe fn vtbx1_u8(a: uint8x8_t, b: uint8x8_t, c: uint8x8_t) -> uint8x8_t {
+    ::mem::transmute(vtbx1(
+        ::mem::transmute(a),
+        ::mem::transmute(b),
+        ::mem::transmute(c),
+    ))
+}
+
+/// Extended table look-up
+#[inline]
+#[cfg(target_arch = "arm")]
+#[cfg(target_endian = "little")]
+#[target_feature(enable = "neon,v7")]
+#[cfg_attr(test, assert_instr(vtbx))]
+pub unsafe fn vtbx1_p8(a: poly8x8_t, b: poly8x8_t, c: uint8x8_t) -> poly8x8_t {
+    ::mem::transmute(vtbx1(
+        ::mem::transmute(a),
+        ::mem::transmute(b),
+        ::mem::transmute(c),
+    ))
+}
+
+/// Extended table look-up
+#[inline]
+#[cfg(target_arch = "arm")]
+#[cfg(target_endian = "little")]
+#[target_feature(enable = "neon,v7")]
+#[cfg_attr(test, assert_instr(vtbx))]
+pub unsafe fn vtbx2_s8(a: int8x8_t, b: int8x8x2_t, c: int8x8_t) -> int8x8_t {
+    vtbx2(a, b.0, b.1, c)
+}
+
+/// Extended table look-up
+#[inline]
+#[cfg(target_arch = "arm")]
+#[cfg(target_endian = "little")]
+#[target_feature(enable = "neon,v7")]
+#[cfg_attr(test, assert_instr(vtbx))]
+pub unsafe fn vtbx2_u8(
+    a: uint8x8_t, b: uint8x8x2_t, c: uint8x8_t,
+) -> uint8x8_t {
+    ::mem::transmute(vtbx2(
+        ::mem::transmute(a),
+        ::mem::transmute(b.0),
+        ::mem::transmute(b.1),
+        ::mem::transmute(c),
+    ))
+}
+
+/// Extended table look-up
+#[inline]
+#[cfg(target_arch = "arm")]
+#[cfg(target_endian = "little")]
+#[target_feature(enable = "neon,v7")]
+#[cfg_attr(test, assert_instr(vtbx))]
+pub unsafe fn vtbx2_p8(
+    a: poly8x8_t, b: poly8x8x2_t, c: uint8x8_t,
+) -> poly8x8_t {
+    ::mem::transmute(vtbx2(
+        ::mem::transmute(a),
+        ::mem::transmute(b.0),
+        ::mem::transmute(b.1),
+        ::mem::transmute(c),
+    ))
+}
+
+/// Extended table look-up
+#[inline]
+#[cfg(target_arch = "arm")]
+#[cfg(target_endian = "little")]
+#[target_feature(enable = "neon,v7")]
+#[cfg_attr(test, assert_instr(vtbx))]
+pub unsafe fn vtbx3_s8(a: int8x8_t, b: int8x8x3_t, c: int8x8_t) -> int8x8_t {
+    vtbx3(a, b.0, b.1, b.2, c)
+}
+
+/// Extended table look-up
+#[inline]
+#[cfg(target_arch = "arm")]
+#[cfg(target_endian = "little")]
+#[target_feature(enable = "neon,v7")]
+#[cfg_attr(test, assert_instr(vtbx))]
+pub unsafe fn vtbx3_u8(
+    a: uint8x8_t, b: uint8x8x3_t, c: uint8x8_t,
+) -> uint8x8_t {
+    ::mem::transmute(vtbx3(
+        ::mem::transmute(a),
+        ::mem::transmute(b.0),
+        ::mem::transmute(b.1),
+        ::mem::transmute(b.2),
+        ::mem::transmute(c),
+    ))
+}
+
+/// Extended table look-up
+#[inline]
+#[cfg(target_arch = "arm")]
+#[cfg(target_endian = "little")]
+#[target_feature(enable = "neon,v7")]
+#[cfg_attr(test, assert_instr(vtbx))]
+pub unsafe fn vtbx3_p8(
+    a: poly8x8_t, b: poly8x8x3_t, c: uint8x8_t,
+) -> poly8x8_t {
+    ::mem::transmute(vtbx3(
+        ::mem::transmute(a),
+        ::mem::transmute(b.0),
+        ::mem::transmute(b.1),
+        ::mem::transmute(b.2),
+        ::mem::transmute(c),
+    ))
+}
+
+/// Extended table look-up
+#[inline]
+#[cfg(target_arch = "arm")]
+#[cfg(target_endian = "little")]
+#[target_feature(enable = "neon,v7")]
+#[cfg_attr(test, assert_instr(vtbx))]
+pub unsafe fn vtbx4_s8(a: int8x8_t, b: int8x8x4_t, c: int8x8_t) -> int8x8_t {
+    vtbx4(a, b.0, b.1, b.2, b.3, c)
+}
+
+/// Extended table look-up
+#[inline]
+#[cfg(target_arch = "arm")]
+#[cfg(target_endian = "little")]
+#[target_feature(enable = "neon,v7")]
+#[cfg_attr(test, assert_instr(vtbx))]
+pub unsafe fn vtbx4_u8(
+    a: uint8x8_t, b: uint8x8x4_t, c: uint8x8_t,
+) -> uint8x8_t {
+    ::mem::transmute(vtbx4(
+        ::mem::transmute(a),
+        ::mem::transmute(b.0),
+        ::mem::transmute(b.1),
+        ::mem::transmute(b.2),
+        ::mem::transmute(b.3),
+        ::mem::transmute(c),
+    ))
+}
+
+/// Extended table look-up
+#[inline]
+#[cfg(target_arch = "arm")]
+#[cfg(target_endian = "little")]
+#[target_feature(enable = "neon,v7")]
+#[cfg_attr(test, assert_instr(vtbx))]
+pub unsafe fn vtbx4_p8(
+    a: poly8x8_t, b: poly8x8x4_t, c: uint8x8_t,
+) -> poly8x8_t {
+    ::mem::transmute(vtbx4(
+        ::mem::transmute(a),
+        ::mem::transmute(b.0),
+        ::mem::transmute(b.1),
+        ::mem::transmute(b.2),
+        ::mem::transmute(b.3),
+        ::mem::transmute(c),
+    ))
+}
+
 #[cfg(test)]
 mod tests {
     use coresimd::arm::*;
@@ -659,7 +1102,10 @@ mod tests {
         let a = i8x8::new(1, 2, 3, 4, 5, 6, 7, 8);
         let b = i8x8::new(8, 7, 6, 5, 4, 3, 2, 1);
         let e = i8x8::new(9, 9, 9, 9, 9, 9, 9, 9);
-        let r: i8x8 = ::mem::transmute(vadd_s8(::mem::transmute(a), ::mem::transmute(b)));
+        let r: i8x8 = ::mem::transmute(vadd_s8(
+            ::mem::transmute(a),
+            ::mem::transmute(b),
+        ));
         assert_eq!(r, e);
     }
 
@@ -668,7 +1114,10 @@ mod tests {
         let a = i8x16::new(1, 2, 3, 4, 5, 6, 7, 8, 1, 2, 3, 4, 5, 6, 7, 8);
         let b = i8x16::new(8, 7, 6, 5, 4, 3, 2, 1, 8, 7, 6, 5, 4, 3, 2, 1);
         let e = i8x16::new(9, 9, 9, 9, 9, 9, 9, 9, 9, 9, 9, 9, 9, 9, 9, 9);
-        let r: i8x16 = ::mem::transmute(vaddq_s8(::mem::transmute(a), ::mem::transmute(b)));
+        let r: i8x16 = ::mem::transmute(vaddq_s8(
+            ::mem::transmute(a),
+            ::mem::transmute(b),
+        ));
         assert_eq!(r, e);
     }
 
@@ -677,7 +1126,10 @@ mod tests {
         let a = i16x4::new(1, 2, 3, 4);
         let b = i16x4::new(8, 7, 6, 5);
         let e = i16x4::new(9, 9, 9, 9);
-        let r: i16x4 = ::mem::transmute(vadd_s16(::mem::transmute(a), ::mem::transmute(b)));
+        let r: i16x4 = ::mem::transmute(vadd_s16(
+            ::mem::transmute(a),
+            ::mem::transmute(b),
+        ));
         assert_eq!(r, e);
     }
 
@@ -686,7 +1138,10 @@ mod tests {
         let a = i16x8::new(1, 2, 3, 4, 5, 6, 7, 8);
         let b = i16x8::new(8, 7, 6, 5, 4, 3, 2, 1);
         let e = i16x8::new(9, 9, 9, 9, 9, 9, 9, 9);
-        let r: i16x8 = ::mem::transmute(vaddq_s16(::mem::transmute(a), ::mem::transmute(b)));
+        let r: i16x8 = ::mem::transmute(vaddq_s16(
+            ::mem::transmute(a),
+            ::mem::transmute(b),
+        ));
         assert_eq!(r, e);
     }
 
@@ -695,7 +1150,10 @@ mod tests {
         let a = i32x2::new(1, 2);
         let b = i32x2::new(8, 7);
         let e = i32x2::new(9, 9);
-        let r: i32x2 = ::mem::transmute(vadd_s32(::mem::transmute(a), ::mem::transmute(b)));
+        let r: i32x2 = ::mem::transmute(vadd_s32(
+            ::mem::transmute(a),
+            ::mem::transmute(b),
+        ));
         assert_eq!(r, e);
     }
 
@@ -704,7 +1162,10 @@ mod tests {
         let a = i32x4::new(1, 2, 3, 4);
         let b = i32x4::new(8, 7, 6, 5);
         let e = i32x4::new(9, 9, 9, 9);
-        let r: i32x4 = ::mem::transmute(vaddq_s32(::mem::transmute(a), ::mem::transmute(b)));
+        let r: i32x4 = ::mem::transmute(vaddq_s32(
+            ::mem::transmute(a),
+            ::mem::transmute(b),
+        ));
         assert_eq!(r, e);
     }
 
@@ -713,7 +1174,10 @@ mod tests {
         let a = u8x8::new(1, 2, 3, 4, 5, 6, 7, 8);
         let b = u8x8::new(8, 7, 6, 5, 4, 3, 2, 1);
         let e = u8x8::new(9, 9, 9, 9, 9, 9, 9, 9);
-        let r: u8x8 = ::mem::transmute(vadd_u8(::mem::transmute(a), ::mem::transmute(b)));
+        let r: u8x8 = ::mem::transmute(vadd_u8(
+            ::mem::transmute(a),
+            ::mem::transmute(b),
+        ));
         assert_eq!(r, e);
     }
 
@@ -722,7 +1186,10 @@ mod tests {
         let a = u8x16::new(1, 2, 3, 4, 5, 6, 7, 8, 1, 2, 3, 4, 5, 6, 7, 8);
         let b = u8x16::new(8, 7, 6, 5, 4, 3, 2, 1, 8, 7, 6, 5, 4, 3, 2, 1);
         let e = u8x16::new(9, 9, 9, 9, 9, 9, 9, 9, 9, 9, 9, 9, 9, 9, 9, 9);
-        let r: u8x16 = ::mem::transmute(vaddq_u8(::mem::transmute(a), ::mem::transmute(b)));
+        let r: u8x16 = ::mem::transmute(vaddq_u8(
+            ::mem::transmute(a),
+            ::mem::transmute(b),
+        ));
         assert_eq!(r, e);
     }
 
@@ -731,7 +1198,10 @@ mod tests {
         let a = u16x4::new(1, 2, 3, 4);
         let b = u16x4::new(8, 7, 6, 5);
         let e = u16x4::new(9, 9, 9, 9);
-        let r: u16x4 = ::mem::transmute(vadd_u16(::mem::transmute(a), ::mem::transmute(b)));
+        let r: u16x4 = ::mem::transmute(vadd_u16(
+            ::mem::transmute(a),
+            ::mem::transmute(b),
+        ));
         assert_eq!(r, e);
     }
 
@@ -740,7 +1210,10 @@ mod tests {
         let a = u16x8::new(1, 2, 3, 4, 5, 6, 7, 8);
         let b = u16x8::new(8, 7, 6, 5, 4, 3, 2, 1);
         let e = u16x8::new(9, 9, 9, 9, 9, 9, 9, 9);
-        let r: u16x8 = ::mem::transmute(vaddq_u16(::mem::transmute(a), ::mem::transmute(b)));
+        let r: u16x8 = ::mem::transmute(vaddq_u16(
+            ::mem::transmute(a),
+            ::mem::transmute(b),
+        ));
         assert_eq!(r, e);
     }
 
@@ -749,7 +1222,10 @@ mod tests {
         let a = u32x2::new(1, 2);
         let b = u32x2::new(8, 7);
         let e = u32x2::new(9, 9);
-        let r: u32x2 = ::mem::transmute(vadd_u32(::mem::transmute(a), ::mem::transmute(b)));
+        let r: u32x2 = ::mem::transmute(vadd_u32(
+            ::mem::transmute(a),
+            ::mem::transmute(b),
+        ));
         assert_eq!(r, e);
     }
 
@@ -758,7 +1234,10 @@ mod tests {
         let a = u32x4::new(1, 2, 3, 4);
         let b = u32x4::new(8, 7, 6, 5);
         let e = u32x4::new(9, 9, 9, 9);
-        let r: u32x4 = ::mem::transmute(vaddq_u32(::mem::transmute(a), ::mem::transmute(b)));
+        let r: u32x4 = ::mem::transmute(vaddq_u32(
+            ::mem::transmute(a),
+            ::mem::transmute(b),
+        ));
         assert_eq!(r, e);
     }
 
@@ -767,7 +1246,10 @@ mod tests {
         let a = f32x2::new(1., 2.);
         let b = f32x2::new(8., 7.);
         let e = f32x2::new(9., 9.);
-        let r: f32x2 = ::mem::transmute(vadd_f32(::mem::transmute(a), ::mem::transmute(b)));
+        let r: f32x2 = ::mem::transmute(vadd_f32(
+            ::mem::transmute(a),
+            ::mem::transmute(b),
+        ));
         assert_eq!(r, e);
     }
 
@@ -776,7 +1258,10 @@ mod tests {
         let a = f32x4::new(1., 2., 3., 4.);
         let b = f32x4::new(8., 7., 6., 5.);
         let e = f32x4::new(9., 9., 9., 9.);
-        let r: f32x4 = ::mem::transmute(vaddq_f32(::mem::transmute(a), ::mem::transmute(b)));
+        let r: f32x4 = ::mem::transmute(vaddq_f32(
+            ::mem::transmute(a),
+            ::mem::transmute(b),
+        ));
         assert_eq!(r, e);
     }
 
@@ -786,7 +1271,10 @@ mod tests {
         let a = i8x8::new(v, v, v, v, v, v, v, v);
         let v = 2 * (v as i16);
         let e = i16x8::new(v, v, v, v, v, v, v, v);
-        let r: i16x8 = ::mem::transmute(vaddl_s8(::mem::transmute(a), ::mem::transmute(a)));
+        let r: i16x8 = ::mem::transmute(vaddl_s8(
+            ::mem::transmute(a),
+            ::mem::transmute(a),
+        ));
         assert_eq!(r, e);
     }
 
@@ -796,7 +1284,10 @@ mod tests {
         let a = i16x4::new(v, v, v, v);
         let v = 2 * (v as i32);
         let e = i32x4::new(v, v, v, v);
-        let r: i32x4 = ::mem::transmute(vaddl_s16(::mem::transmute(a), ::mem::transmute(a)));
+        let r: i32x4 = ::mem::transmute(vaddl_s16(
+            ::mem::transmute(a),
+            ::mem::transmute(a),
+        ));
         assert_eq!(r, e);
     }
 
@@ -806,7 +1297,10 @@ mod tests {
         let a = i32x2::new(v, v);
         let v = 2 * (v as i64);
         let e = i64x2::new(v, v);
-        let r: i64x2 = ::mem::transmute(vaddl_s32(::mem::transmute(a), ::mem::transmute(a)));
+        let r: i64x2 = ::mem::transmute(vaddl_s32(
+            ::mem::transmute(a),
+            ::mem::transmute(a),
+        ));
         assert_eq!(r, e);
     }
 
@@ -816,7 +1310,10 @@ mod tests {
         let a = u8x8::new(v, v, v, v, v, v, v, v);
         let v = 2 * (v as u16);
         let e = u16x8::new(v, v, v, v, v, v, v, v);
-        let r: u16x8 = ::mem::transmute(vaddl_u8(::mem::transmute(a), ::mem::transmute(a)));
+        let r: u16x8 = ::mem::transmute(vaddl_u8(
+            ::mem::transmute(a),
+            ::mem::transmute(a),
+        ));
         assert_eq!(r, e);
     }
 
@@ -826,7 +1323,10 @@ mod tests {
         let a = u16x4::new(v, v, v, v);
         let v = 2 * (v as u32);
         let e = u32x4::new(v, v, v, v);
-        let r: u32x4 = ::mem::transmute(vaddl_u16(::mem::transmute(a), ::mem::transmute(a)));
+        let r: u32x4 = ::mem::transmute(vaddl_u16(
+            ::mem::transmute(a),
+            ::mem::transmute(a),
+        ));
         assert_eq!(r, e);
     }
 
@@ -836,7 +1336,10 @@ mod tests {
         let a = u32x2::new(v, v);
         let v = 2 * (v as u64);
         let e = u64x2::new(v, v);
-        let r: u64x2 = ::mem::transmute(vaddl_u32(::mem::transmute(a), ::mem::transmute(a)));
+        let r: u64x2 = ::mem::transmute(vaddl_u32(
+            ::mem::transmute(a),
+            ::mem::transmute(a),
+        ));
         assert_eq!(r, e);
     }
 
@@ -949,7 +1452,10 @@ mod tests {
         let a = i8x8::new(1, -2, 3, -4, 5, 6, 7, 8);
         let b = i8x8::new(0, 3, 2, 5, 4, 7, 6, 9);
         let e = i8x8::new(-2, -4, 5, 7, 0, 2, 4, 6);
-        let r: i8x8 = ::mem::transmute(vpmin_s8(::mem::transmute(a), ::mem::transmute(b)));
+        let r: i8x8 = ::mem::transmute(vpmin_s8(
+            ::mem::transmute(a),
+            ::mem::transmute(b),
+        ));
         assert_eq!(r, e);
     }
 
@@ -958,7 +1464,10 @@ mod tests {
         let a = i16x4::new(1, 2, 3, -4);
         let b = i16x4::new(0, 3, 2, 5);
         let e = i16x4::new(1, -4, 0, 2);
-        let r: i16x4 = ::mem::transmute(vpmin_s16(::mem::transmute(a), ::mem::transmute(b)));
+        let r: i16x4 = ::mem::transmute(vpmin_s16(
+            ::mem::transmute(a),
+            ::mem::transmute(b),
+        ));
         assert_eq!(r, e);
     }
 
@@ -967,7 +1476,10 @@ mod tests {
         let a = i32x2::new(1, -2);
         let b = i32x2::new(0, 3);
         let e = i32x2::new(-2, 0);
-        let r: i32x2 = ::mem::transmute(vpmin_s32(::mem::transmute(a), ::mem::transmute(b)));
+        let r: i32x2 = ::mem::transmute(vpmin_s32(
+            ::mem::transmute(a),
+            ::mem::transmute(b),
+        ));
         assert_eq!(r, e);
     }
 
@@ -976,7 +1488,10 @@ mod tests {
         let a = u8x8::new(1, 2, 3, 4, 5, 6, 7, 8);
         let b = u8x8::new(0, 3, 2, 5, 4, 7, 6, 9);
         let e = u8x8::new(1, 3, 5, 7, 0, 2, 4, 6);
-        let r: u8x8 = ::mem::transmute(vpmin_u8(::mem::transmute(a), ::mem::transmute(b)));
+        let r: u8x8 = ::mem::transmute(vpmin_u8(
+            ::mem::transmute(a),
+            ::mem::transmute(b),
+        ));
         assert_eq!(r, e);
     }
 
@@ -985,7 +1500,10 @@ mod tests {
         let a = u16x4::new(1, 2, 3, 4);
         let b = u16x4::new(0, 3, 2, 5);
         let e = u16x4::new(1, 3, 0, 2);
-        let r: u16x4 = ::mem::transmute(vpmin_u16(::mem::transmute(a), ::mem::transmute(b)));
+        let r: u16x4 = ::mem::transmute(vpmin_u16(
+            ::mem::transmute(a),
+            ::mem::transmute(b),
+        ));
         assert_eq!(r, e);
     }
 
@@ -994,7 +1512,10 @@ mod tests {
         let a = u32x2::new(1, 2);
         let b = u32x2::new(0, 3);
         let e = u32x2::new(1, 0);
-        let r: u32x2 = ::mem::transmute(vpmin_u32(::mem::transmute(a), ::mem::transmute(b)));
+        let r: u32x2 = ::mem::transmute(vpmin_u32(
+            ::mem::transmute(a),
+            ::mem::transmute(b),
+        ));
         assert_eq!(r, e);
     }
 
@@ -1003,7 +1524,10 @@ mod tests {
         let a = f32x2::new(1., -2.);
         let b = f32x2::new(0., 3.);
         let e = f32x2::new(-2., 0.);
-        let r: f32x2 = ::mem::transmute(vpmin_f32(::mem::transmute(a), ::mem::transmute(b)));
+        let r: f32x2 = ::mem::transmute(vpmin_f32(
+            ::mem::transmute(a),
+            ::mem::transmute(b),
+        ));
         assert_eq!(r, e);
     }
 
@@ -1012,7 +1536,10 @@ mod tests {
         let a = i8x8::new(1, -2, 3, -4, 5, 6, 7, 8);
         let b = i8x8::new(0, 3, 2, 5, 4, 7, 6, 9);
         let e = i8x8::new(1, 3, 6, 8, 3, 5, 7, 9);
-        let r: i8x8 = ::mem::transmute(vpmax_s8(::mem::transmute(a), ::mem::transmute(b)));
+        let r: i8x8 = ::mem::transmute(vpmax_s8(
+            ::mem::transmute(a),
+            ::mem::transmute(b),
+        ));
         assert_eq!(r, e);
     }
 
@@ -1021,7 +1548,10 @@ mod tests {
         let a = i16x4::new(1, 2, 3, -4);
         let b = i16x4::new(0, 3, 2, 5);
         let e = i16x4::new(2, 3, 3, 5);
-        let r: i16x4 = ::mem::transmute(vpmax_s16(::mem::transmute(a), ::mem::transmute(b)));
+        let r: i16x4 = ::mem::transmute(vpmax_s16(
+            ::mem::transmute(a),
+            ::mem::transmute(b),
+        ));
         assert_eq!(r, e);
     }
 
@@ -1030,7 +1560,10 @@ mod tests {
         let a = i32x2::new(1, -2);
         let b = i32x2::new(0, 3);
         let e = i32x2::new(1, 3);
-        let r: i32x2 = ::mem::transmute(vpmax_s32(::mem::transmute(a), ::mem::transmute(b)));
+        let r: i32x2 = ::mem::transmute(vpmax_s32(
+            ::mem::transmute(a),
+            ::mem::transmute(b),
+        ));
         assert_eq!(r, e);
     }
 
@@ -1039,7 +1572,10 @@ mod tests {
         let a = u8x8::new(1, 2, 3, 4, 5, 6, 7, 8);
         let b = u8x8::new(0, 3, 2, 5, 4, 7, 6, 9);
         let e = u8x8::new(2, 4, 6, 8, 3, 5, 7, 9);
-        let r: u8x8 = ::mem::transmute(vpmax_u8(::mem::transmute(a), ::mem::transmute(b)));
+        let r: u8x8 = ::mem::transmute(vpmax_u8(
+            ::mem::transmute(a),
+            ::mem::transmute(b),
+        ));
         assert_eq!(r, e);
     }
 
@@ -1048,7 +1584,10 @@ mod tests {
         let a = u16x4::new(1, 2, 3, 4);
         let b = u16x4::new(0, 3, 2, 5);
         let e = u16x4::new(2, 4, 3, 5);
-        let r: u16x4 = ::mem::transmute(vpmax_u16(::mem::transmute(a), ::mem::transmute(b)));
+        let r: u16x4 = ::mem::transmute(vpmax_u16(
+            ::mem::transmute(a),
+            ::mem::transmute(b),
+        ));
         assert_eq!(r, e);
     }
 
@@ -1057,7 +1596,10 @@ mod tests {
         let a = u32x2::new(1, 2);
         let b = u32x2::new(0, 3);
         let e = u32x2::new(2, 3);
-        let r: u32x2 = ::mem::transmute(vpmax_u32(::mem::transmute(a), ::mem::transmute(b)));
+        let r: u32x2 = ::mem::transmute(vpmax_u32(
+            ::mem::transmute(a),
+            ::mem::transmute(b),
+        ));
         assert_eq!(r, e);
     }
 
@@ -1066,7 +1608,15 @@ mod tests {
         let a = f32x2::new(1., -2.);
         let b = f32x2::new(0., 3.);
         let e = f32x2::new(1., 3.);
-        let r: f32x2 = ::mem::transmute(vpmax_f32(::mem::transmute(a), ::mem::transmute(b)));
+        let r: f32x2 = ::mem::transmute(vpmax_f32(
+            ::mem::transmute(a),
+            ::mem::transmute(b),
+        ));
         assert_eq!(r, e);
     }
 }
+
+#[cfg(test)]
+#[cfg(target_endian = "little")]
+#[path = "table_lookup_tests.rs"]
+mod table_lookup_tests;
